<?php

namespace Wachat\Api;

use WP_REST_Server;

class Tools extends Base {

    /**
     * Initialize
     *
     * @return void
     */
    public function __construct() {
        $this->namespace = 'wachat/v1';
        $this->rest_base = 'tools';
    }

    /**
     * Registers the routes for the objects of the controller.
     *
     * @return void
     */
    public function register_routes() {
        register_rest_route(
            $this->namespace,
            '/' . $this->rest_base . '/test',
            [
                [
                    'methods'             => WP_REST_Server::CREATABLE,
                    'callback'            => [ $this, 'test_send' ],
                    'permission_callback' => [ $this, 'admin_permissions_check' ],
                    'args'                => [
                        'to' => [
                            'description' => __( 'The to phone number', 'wachat' ),
                            'type'        => 'string',
                            'required'    => true,
                        ],
                    ],
                ],
            ]
        );
    }

    /*
     * Send a test.
     *
     * @param WP_Rest_Request $request
     *
     * @return WP_Rest_Response|WP_Error
     */
    public function test_send( $request ) {
        $to      = $request->get_param( 'to' );
        $message = '🎉 This is a test message from WaChat - WhatsApp Notification for WordPress';

        $status = wachat()->gateways()->send( $to, $message );

        $response = [
            'success' => is_wp_error( $status ) ? true : true,
            'message' => is_wp_error( $status ) ? $status->get_error_message() : '',
        ];

        return rest_ensure_response( $response );
    }
}
