<?php

namespace Wachat\Gateways;

use WP_Error;

/**
 * Nexmo Class
 *
 * @see https://developer.wachat.net/
 */
class Wachat implements GatewayInterface {

    /**
     * API Endpoint
     */
    const ENDPOINT = 'https://api.wachat.net';

    /**
     * Get the name
     *
     * @return string
     */
    public function name() {
        
    }

    /**
     * Get the logo
     *
     * @return string
     */
    public function logo() {
        return WACHAT_URL . '/assets/images/wachat.png';
    }
    /**
     * Get the name
     *
     * @return string
     */
    public function description() {
        return sprintf(
            // translators: Wachat dashboard settings URL and help docs
            __(
                'Send WhatsApp message with Wachat. Follow <a href="%1$s" target="_blank">this link</a> to get the <b>API Token</b> from Wachat.',
                'wachat'
            ),
            'https://app.wachat.net/'
        );
    }

    /**
     * Get the settings
     *
     * @return array
     */
    public function get_settings() {
        $creds = wachat()->settings()->get( 'wachat' );

        return [
            'key' => [
                'name'  => __( 'API Token', 'wachat' ),
                'type'  => 'text',
                'value' => isset( $creds['key'] ) ? $creds['key'] : '',
                'help'  => '',
            ],
            
            
        ];
    }

    /**
     * Send SMS
     *
     * @param string $to
     * @param string $message
     *
     * @return WP_Error|bool
     */
    public function send( $to, $message ) {
        $creds = wachat()->settings()->get( 'wachat' );

        $args = [
            'body' => [
				'receiver'         => $to,
                'msgtext'       => $message,
				'token'    => $creds['key'],
            ],
        ];

        $request       = wp_remote_post( self::ENDPOINT . '/send?', $args );
        $body          = json_decode( wp_remote_retrieve_body( $request ) );
        $response_code = wp_remote_retrieve_response_code( $request );

        if ( is_wp_error( $request ) ) {
            return $request;
        }

        if ( $body->messages[0]->status !== '0' ) {
            return new WP_Error(
                $body->messages[0]->status,
                $body->messages[0]->{'error-text'}
            );
        }

        return true;
    }

    /**
     * Validate a REST API request
     *
     * @param WP_REST_Request $request
     *
     * @return WP_Error|true
     */
    public function validate( $request ) {
        $creds = $request->get_param( 'wachat' );

        $args = [
            'appkey'    => $creds['key'],
            'authkey' => $creds['secret'],
        ];

        $endpoint      = self::ENDPOINT . '/account/get-balance?' . http_build_query( $args );
        $response      = wp_remote_get( $endpoint, $args );
        $body          = json_decode( wp_remote_retrieve_body( $response ) );
        $response_code = wp_remote_retrieve_response_code( $response );

        if ( 200 === $response_code ) {
            return new WP_Error(
                $body->{'error-code'},
                $body->{'error-code-label'}
            );
        }

        return [
            'key'    => $creds['key'],
            'secret' => $creds['secret'],
            
        ];
    }
}
