<?php
/**
 * Plugin Name: Wachat
 * Description: WhatsApp Notification for WordPress
 * Plugin URI: https://wachat.net/
 * Author: Wachat
 * Author URI: https://wachat.net/
 * Version: 2.1
 * License: GPL2 or later
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain: wachat
 */
defined( 'ABSPATH' ) || exit;

require __DIR__ . '/vendor/autoload.php';

/**
 * Wachat Class
 */
final class Wachat {

    /**
     * Plugin version
     *
     * @var string
     */
    private $version = '1.1.1';

    /**
     * Instances array
     *
     * @var array
     */
    private $instances = [];

    /**
     * Initialize
     */
    public function __construct() {
        $this->define_constants();
        $this->appsero_init();

        // run the installer
        register_activation_hook( __FILE__, [ $this, 'activate' ] );

        // load the plugin
        add_action( 'plugins_loaded', [ $this, 'init_plugin' ] );
    }

    /**
     * Initializes the Wachat class
     *
     * Checks for an existing Wachat instance
     * and if it doesn't find one, creates it.
     */
    public static function instance() {
        static $instance = false;

        if ( ! $instance ) {
            $instance = new self();
        }

        return $instance;
    }

    /**
     * Initialize the plugin
     *
     * @return void
     */
    public function init_plugin() {
        if ( is_admin() ) {
            new Wachat\Admin();
        }

        new Wachat\Api();
        new Wachat\Dispatcher();
    }

    /**
     * Define constants
     *
     * @return void
     */
    private function define_constants() {
        define( 'WACHAT_VERSION', $this->version );
        define( 'WACHAT_DIR', __DIR__ );
        define( 'WACHAT_FILE', __FILE__ );
        define( 'WACHAT_URL', plugins_url( '', __FILE__ ) );
    }

    /**
     * Run the installer
     *
     * @return void
     */
    public function activate() {
        $installer = new Wachat\Install();
        $installer->run();
    }

    /**
     * Access to gateway manager
     *
     * @return Wachat\Gateways
     */
    public function gateways() {
        if ( ! isset( $this->instances['gateway'] ) ) {
            $this->instances['gateway'] = new \Wachat\Gateways();
        }

        return $this->instances['gateway'];
    }

    /**
     * Access to gateway manager
     *
     * @return Wachat\Settings
     */
    public function settings() {
        if ( ! isset( $this->instances['settings'] ) ) {
            $this->instances['settings'] = new \Wachat\Settings();
        }

        return $this->instances['settings'];
    }

    /**
     * Access to gateway manager
     *
     * @return Wachat\Notifications
     */
    public function notifications() {
        if ( ! isset( $this->instances['notification'] ) ) {
            $this->instances['notification'] = new \Wachat\Notifications();
        }

        return $this->instances['notification'];
    }

    /**
     * Initialize the plugin tracker
     *
     * @return void
     */
    public function appsero_init() {
        $client = new Appsero\Client( 'd54ca4c0-9730-4e1a-a195-5c9018131711', 'Wachat', __FILE__ );

        // Active insights
        $client->insights()->init();
    }
}

/**
 * Return the instance
 *
 * @return \Wachat
 */
function wachat() {
    return Wachat::instance();
}

// take off
wachat();
